@@ -1,14 +1,12 @@
-# $Id: MinSizeGroup.pm,v 1.3 2004/04/11 23:36:20 joern Exp $
+# $Id: MinSizeGroup.pm,v 1.1 2002/04/06 10:26:48 joern Exp $
 
 package Video::DVDRip::GUI::MinSizeGroup;
-use Locale::TextDomain qw (video.dvdrip);
 
 use strict;
 use Carp;
 
 sub size_aloc_arg		{ shift->{size_aloc_arg}		}
 sub widgets			{ shift->{widgets}			}
-sub debug			{ shift->{debug}			}
 
 sub maximum			{ shift->{maximum}			}
 sub set_maximum			{ shift->{maximum}		= $_[1] }
@@ -18,7 +16,7 @@ sub set_signals_received	{ shift->{signals_received}	= $_[1] }
 sub new {
 	my $class = shift;
 	my %par = @_;
-	my ($type, $debug) = @par{'type','debug'};
+	my ($type) = @par{'type'};
 	
 	# v - control vertical size, h - control horizontal size
 	croak "type must be 'h' or 'v'"
@@ -29,7 +27,6 @@ sub new {
 		type    	 => $type,
 		maximum		 => 0,
 		signals_received => 0,
-		debug            => $debug,
 
 		# index of the size-alloc callback argument
 		# for this type
@@ -43,8 +40,6 @@ sub add {
 	my $self = shift;
 	my ($widget) = @_;
 	
-	$self->debug && print "MinSizeGroup: added widget $widget\n";
-
 	push @{$self->widgets}, $widget;
 	
 	# Track size-alloc signals which are sent when
@@ -69,9 +64,6 @@ sub note_size {
 	my  ($widget, $value, $signal) =
 	@par{'widget','value','signal'};
 	
-	$self->debug && print "MinSizeGroup: got signal for widget $widget. ".
-			      "value=$value max=".$self->maximum."\n";
-
 	# track maximum value
 	$self->set_maximum($value) if $value > $self->maximum;
 
